@@ -4,7 +4,7 @@ import requests
 responses = []
 questions = []
 
-def SetUrl(url):
+def url(url):
     global form_url
     global questions
     form_url = url
@@ -23,7 +23,7 @@ def SetUrl(url):
     form_url = form_url + "formResponse"
 
 
-def FormResponse(question, response):
+def response(question, response):
     global responses
     if form_url:
         try:
@@ -31,11 +31,11 @@ def FormResponse(question, response):
         except:
             responses.append(response)
 
-def SendResponses():
+def send():
     data = {}
     qr = dict(zip(questions, responses))
     data.update(qr)
     headers = {"User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36"}
     r = requests.post(url=form_url, data=data, headers=headers)
     if r.status_code != 200:
-        print("[404] googleForms: Something went wrong. Check the documentation for more information.")
\ No newline at end of file
+        print("[404] FormResponses: Something went wrong. Check the documentation for more information. https://github.com/J3pe/FormResponses")
\ No newline at end of file
